@@ -1,6 +1,10 @@
 """
 See README.md  for details
 """
+from treepath.descriptor.descriptor_functions import attr, attr_typed
+from treepath.descriptor.descriptor_functions import attr_iter_typed, attr_list_typed
+from treepath.descriptor.document import Document
+from treepath.descriptor.path_descriptor import PathDescriptor
 from treepath.path.builder.dash_path_builder import DashPathRoot
 from treepath.path.builder.patch_constants import rec
 from treepath.path.builder.patch_constants import recursive
@@ -11,6 +15,8 @@ from treepath.path.exceptions.infinite_loop_detected import InfiniteLoopDetected
 from treepath.path.exceptions.match_not_found_error import MatchNotFoundError
 from treepath.path.exceptions.nested_match_not_found_error import NestedMatchNotFoundError
 from treepath.path.exceptions.path_syntax_error import PathSyntaxError
+from treepath.path.exceptions.pop_error import PopError
+from treepath.path.exceptions.set_error import SetError
 from treepath.path.exceptions.stop_traversing import StopTraversing
 from treepath.path.exceptions.traversing_error import TraversingError
 from treepath.path.exceptions.treepath_exception import TreepathException
@@ -27,6 +33,14 @@ from treepath.path.traverser.traverser_functions import has_any
 from treepath.path.traverser.traverser_functions import has_not
 from treepath.path.traverser.traverser_functions import nested_find_matches
 from treepath.path.traverser.traverser_functions import nested_get_match
+from treepath.path.traverser.traverser_functions import pop
+from treepath.path.traverser.traverser_functions import pop_match
+from treepath.path.traverser.traverser_functions import set_
+from treepath.path.traverser.traverser_functions import set_match
+from treepath.path.typing.json_arg_types import JsonArgTypes
+from treepath.path.typing.json_arg_types import JsonTypes
+from treepath.path.utils.path_property import mprop
+from treepath.path.utils.path_property import pprop
 
 # path is a global object for dynamically declaring a query to extract data from a json data structure.
 #     # A treepath example that fetches the value 1 from data.
